import {
  APICreate,
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { steeringAuthInit } from '@/stores/auth'
import { Episode, EpisodeCreateData, EpisodeUpdateData } from '@/types'
import { aggregateWithIdsParameter } from '@/util/api'

export const useEpisodeStore = defineStore('episodes', () => {
  const endpoint = createSteeringURL.prefix('episodes')
  const { api, base } = createExtendableAPI<Episode>(endpoint, steeringAuthInit)
  const listOperations = APIListPaginated(api)
  return {
    ...base,
    ...listOperations,
    ...APIRetrieve(api, {
      aggregate: aggregateWithIdsParameter(listOperations.listIsolated),
    }),
    ...APICreate<Episode, EpisodeCreateData>(api),
    ...APIUpdate<Episode, EpisodeUpdateData>(api),
    ...APIRemove(api),
  }
})
